Method: Echochamber::User#initialize
- Defined in:
- lib/echochamber/user.rb
#initialize(params) ⇒ String
Creates a user for the current application
Parameters:
-
params
(Hash)
—
SYMBOL-referenced Hash containing:
Options Hash (params):
-
:email
(String)
—
User’s email address (REQUIRED)
-
:password
(String)
—
The new user’s password (REQUIRED)
-
:firstName
(String)
—
The first name of the new user (REQUIRED)
-
:lastName
(String)
—
The last name of the new user (REQUIRED)
-
:optIn
(String)
—
‘YES’ or ‘NO’ or ‘UNKNOWN’: Whether or not the user has opted in to recieve marketing information from EchoSign and its partners. Default value is UNKNOWN
-
:groupId
(String)
—
Group in which the new user should be added. It can be obtained through GET /users call. Default is Group of the user making this call. The user is inferred from the access_token header
-
:title
(String)
—
The new user’s job title
-
:phone
(String)
—
The phone number of the new user
-
:company
(String)
—
The name of the new user’s company
-
:customField1
(String)
—
You can choose to use custom fields to record additional information about your new users. These fields are, however, available only with customized implementations - please contact EchoSign if you would like to make use of this functionality
-
:customField2
(String)
—
You can choose to use custom fields to record additional information about your new users. These fields are, however, available only with customized implementations - please contact EchoSign if you would like to make use of this functionality
-
:customField3
(String)
—
You can choose to use custom fields to record additional information about your new users. These fields are, however, available only with customized implementations - please contact EchoSign if you would like to make use of this functionality
23 24 25 26 |
# File 'lib/echochamber/user.rb', line 23 def initialize(params) require_keys([:firstName, :lastName, :email, :password], params) merge!(params) end |